@@ -95,7 +95,7 @@ class _InstructionContainer:
     # takes a pre-listed group (each group is an iterator itself)
     def _merge(self, fn, other):
         self._insts.append({
-            'cmd': 'merge',
+            'cmd': '_merge',
             'fn': fn,
             'other': other
         })
@@ -116,6 +116,12 @@ class _InstructionContainer:
         })
         return self
 
+    def flatten(self):
+        def flattenfn(rs):
+            yield from rs
+
+        return self._map(flattenfn)
+
     def filter(self, pred):
         def predicate2gen(pred):
             def gen(r):
@@ -214,6 +220,12 @@ class _InstructionContainer:
 
         return self._merge_with_columns(fulljoin_fn, other)
 
+    def distinct(self, *columns):
+        def distinctfn(rs):
+            yield next(rs)
+
+        return self.by(*columns)._map(distinctfn)
+
     def iter(self):
         insts = self._insts
         # If the second instruction is 'by', combine it with the first
@@ -244,7 +256,7 @@ class _InstructionContainer:
         for pinst, inst in zip(insts, insts[1:]):
             # Scan through the instructions and stack up 'genfns'
             # with generators
-            if inst['cmd'] == 'map':
+            if inst['cmd'] == 'map' or inst['cmd'] == '_map':
 
                 def buildgen(pinst, inst):
                     fn = _fn2gen(inst['fn'])
@@ -289,7 +301,7 @@ class _InstructionContainer:
 
                 genfns.append(buildgen(inst))
 
-            elif inst['cmd'] == 'merge':
+            elif inst['cmd'] == 'merge' or inst['cmd'] == '_merge':
                 if not 'by' in pinst['cmd']:
                     raise ValueError("Must be grouped by columns before merge")
 
