@@ -279,3 +279,30 @@ class TestDerivs(unittest.TestCase):
                           {'col1': 'b', 'col2': 1, 'tot': 1},
                           {'col1': 'c', 'col2': 3, 'tot': 14},
                           {'col1': 'd', 'col2': 2, 'tot': 2}])
+
+    def test_distinct(self):
+        conn = Conn(self.dbfile)
+        conn['t1'] = table1
+        conn['t1_1'] = conn['t1'].distinct('col1')
+        self.assertEqual(len(conn['t1_1'].list()), 4)
+        conn['t1_2'] = conn['t1'].distinct('col1', 'col2')
+        self.assertEqual(len(conn['t1_2'].list()), 7)
+
+    def test_flatten(self):
+        conn = Conn(self.dbfile)
+        conn['t2'] = table2
+        self.assertEqual(conn['t2'].by('col1').flatten().list(), [
+            {'col1': 'b', 'col3': 1},
+            {'col1': 'd', 'col3': 3},
+            {'col1': 'd', 'col3': 2},
+            {'col1': 'e', 'col3': 3},
+            {'col1': 'e', 'col3': 4}]
+        )
+
+        self.assertEqual(conn['t2'].by('col1', 'col3').flatten().list(), [
+            {'col1': 'b', 'col3': 1},
+            {'col1': 'd', 'col3': 2},
+            {'col1': 'd', 'col3': 3},
+            {'col1': 'e', 'col3': 3},
+            {'col1': 'e', 'col3': 4}]
+        )
